package cmd

import (
	"github.com/spf13/cobra"
	"libre.sh/cli/pkg/rocketchat"
)

var rc = &cobra.Command{
	Use:     "rocketchat",
	Aliases: []string{"rc"},
	Short:   "All Rocket.Chat subcommands",
}

var rcUser = &cobra.Command{
	Use:   "user",
	Short: "Manipulate users",
}

var rcUserPassword = &cobra.Command{
	Use:        "password",
	Aliases:    []string{"pass"},
	Short:      "Change a user password",
	Args:       cobra.ExactArgs(2),
	ArgAliases: []string{"username", "password"},
	Run: func(cmd *cobra.Command, args []string) {
		f := KubeFactory()
		rcc := rocketchat.New(f)
		namespace, _, err := f.ToRawKubeConfigLoader().Namespace()
		cobra.CheckErr(err)
		rci, err := rcc.Get(namespace, args[0])
		cobra.CheckErr(err)
		ms, err := rci.MongoPrimaryServer()
		cobra.CheckErr(err)
		client, err := ms.MongoClient()
		cobra.CheckErr(err)
		rci.RocketChatRestAdminPass(client, args[0], args[1])
	},
}

var rcUserCount = &cobra.Command{
	Use:   "count",
	Short: "Count users",
	Run: func(cmd *cobra.Command, args []string) {
		f := KubeFactory()
		rcc := rocketchat.New(f)
		namespace, _, err := f.ToRawKubeConfigLoader().Namespace()
		cobra.CheckErr(err)
		rci, err := rcc.Get(namespace, args[0])
		cobra.CheckErr(err)
		ms, err := rci.MongoPrimaryServer()
		cobra.CheckErr(err)
		client, err := ms.MongoClient()
		cobra.CheckErr(err)
		active, _ := cmd.Flags().GetBool("active")
		lastLogin, _ := cmd.Flags().GetInt("last-login")
		err = rci.RocketChatUserCount(client, active, lastLogin)
		cobra.CheckErr(err)
	},
}

// var rcLs = &cobra.Command{
// 	Use:   "ls",
// 	Short: "List Rocket.Chats",
// 	Run: func(cmd *cobra.Command, args []string) {
// 		f := KubeFactory()
// 		namespace, _, _ := f.ToRawKubeConfigLoader().Namespace()
// 		list := rocketchat.List(f, namespace)
// 		fmt.Println("NAME")
// 		for _, v := range list {
// 			fmt.Printf("%s\n", v.Name)
// 		}
// 	},
// }

func init() {
	rootCmd.AddCommand(rc)
	rc.AddCommand(rcUser)
	rcUser.AddCommand(rcUserPassword)
	rcUser.AddCommand(rcUserCount)
	rcUserCount.Flags().Bool("active", false, "Only active users")
	rcUserCount.Flags().Int("last-login", 0, "Users logged in during the last X days.")
	AddKubeFlags(rcUserPassword)
	AddKubeFlags(rcUserCount)
}
