package rocketchat

import (
	"context"
	"errors"
	"fmt"

	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	"k8s.io/apimachinery/pkg/types"
	cmdutil "k8s.io/kubectl/pkg/cmd/util"
)

type RocketChatClient struct {
	cmdutil.Factory
}

func New(factory cmdutil.Factory) RocketChatClient {
	return RocketChatClient{
		factory,
	}
}

func (rcc *RocketChatClient) List(namespace string) ([]RocketChatInstance, error) {
	client, err := rcc.KubernetesClientSet()
	if err != nil {
		return nil, err
	}
	deployments, err := client.AppsV1().Deployments(namespace).List(context.TODO(), metav1.ListOptions{
		LabelSelector: "app.kubernetes.io/name=Rocketchat",
	})
	if err != nil {
		return nil, err
	}
	list := []RocketChatInstance{}
	for _, v := range deployments.Items {
		instance := RocketChatInstance{
			RocketChatClient: rcc,
			Name:             v.Labels["app.kubernetes.io/instance"],
			deploymentRef: types.NamespacedName{
				Name:      v.Name,
				Namespace: v.Namespace,
			},
		}
		list = append(list, instance)
	}
	return list, nil
}

func (rcc *RocketChatClient) Get(namespace string, name string) (*RocketChatInstance, error) {
	client, err := rcc.KubernetesClientSet()
	if err != nil {
		return nil, err
	}
	deployments, err := client.AppsV1().Deployments(namespace).List(context.TODO(), metav1.ListOptions{
		LabelSelector: fmt.Sprintf("app.kubernetes.io/name=Rocketchat,app.kubernetes.io/instance=%s", name),
	})
	if err != nil {
		return nil, err
	}
	if len(deployments.Items) > 1 {
		return nil, errors.New("multiple deployments found")
	}
	deployment := deployments.Items[0]
	instance := RocketChatInstance{
		RocketChatClient: rcc,
		Name:             deployment.Labels["app.kubernetes.io/instance"],
		deploymentRef: types.NamespacedName{
			Name:      deployment.Name,
			Namespace: deployment.Namespace,
		},
	}
	return &instance, nil
}
