package rocketchat

import (
	"context"

	appv1 "k8s.io/api/apps/v1"
	corev1 "k8s.io/api/core/v1"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	"k8s.io/apimachinery/pkg/types"
)

type RocketChatInstance struct {
	*RocketChatClient
	Name               string
	deploymentRef      types.NamespacedName
	deployment         *appv1.Deployment
	mongoServers       []MongoServer
	mongoPrimaryServer *MongoServer
	mongoSecret        *corev1.Secret
}

func (rci *RocketChatInstance) Deployment() (appv1.Deployment, error) {
	if rci.deployment != nil {
		return *rci.deployment, nil
	}
	client, err := rci.KubernetesClientSet()
	if err != nil {
		return appv1.Deployment{}, err
	}
	deployment, err := client.AppsV1().Deployments(rci.deploymentRef.Namespace).Get(context.TODO(), rci.deploymentRef.Name, metav1.GetOptions{})
	if err != nil {
		return appv1.Deployment{}, err
	}
	rci.deployment = deployment
	return *deployment, nil
}
